RDFCalendar.FormatWriters.DOMWriter

Package RDFCalendar :: Module FormatWriters :: Class DOMWriter |
[show private | hide private]
[frames | no frames]

## Class DOMWriter

    DOMWriter --+
                |
               DOMWriter

    A DOM document writer.

Method Summary
| `get_item_type_name(self, label)`
| `get_property_label(self, property_name)`
| `get_property_name(self, attribute_name)`
Inherited from DOMWriter
| ``__init__`(self, doc, root, qualifier, value_as_attribute)` Initialise the writer with the document 'doc' to be written to, the element 'root' within which information is to be inserted.
| ``close`(self)`
| ``end_element`(self, label)`
| ``start_element`(self, label)`
| ``write_attribute`(self, name, modifiers, value, subvalues, multivalues)`

Generated by Epydoc 2.1 on Tue Sep 18 23:33:17 2007 | http://epydoc.sf.net